package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.RegisterSchool;

/**
 * 注册-学校Mapper接口
 * 
 * @author ruoyi
 * @date 2023-05-24
 */
public interface RegisterSchoolMapper 
{
    /**
     * 查询注册-学校
     * 
     * @param id 注册-学校主键
     * @return 注册-学校
     */
    public RegisterSchool selectRegisterSchoolById(Long id);

    /**
     * 查询注册-学校列表
     * 
     * @param registerSchool 注册-学校
     * @return 注册-学校集合
     */
    public List<RegisterSchool> selectRegisterSchoolList(RegisterSchool registerSchool);

    /**
     * 新增注册-学校
     * 
     * @param registerSchool 注册-学校
     * @return 结果
     */
    public int insertRegisterSchool(RegisterSchool registerSchool);

    /**
     * 修改注册-学校
     * 
     * @param registerSchool 注册-学校
     * @return 结果
     */
    public int updateRegisterSchool(RegisterSchool registerSchool);

    /**
     * 删除注册-学校
     * 
     * @param id 注册-学校主键
     * @return 结果
     */
    public int deleteRegisterSchoolById(Long id);

    /**
     * 批量删除注册-学校
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRegisterSchoolByIds(Long[] ids);

    RegisterSchool selectRegisterSchooByOppenId(String openId);

    void deleteRegisterSchoolByOpenId(String openId);
}
