package com.ruoyi.web.controller.register;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.RegisterSchool;
import com.ruoyi.system.service.IRegisterSchoolService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 注册-学校Controller
 * 
 * @author ruoyi
 * @date 2023-05-24
 */
@RestController
@RequestMapping("/register/school")
public class RegisterSchoolController extends BaseController
{
    @Autowired
    private IRegisterSchoolService registerSchoolService;

    /**
     * 查询注册-学校列表
     */
    @PreAuthorize("@ss.hasPermi('register:school:list')")
    @GetMapping("/list")
    public TableDataInfo list(RegisterSchool registerSchool)
    {
        startPage();
        List<RegisterSchool> list = registerSchoolService.selectRegisterSchoolList(registerSchool);
        return getDataTable(list);
    }

    /**
     * 导出注册-学校列表
     */
    @PreAuthorize("@ss.hasPermi('register:school:export')")
    @Log(title = "注册-学校", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RegisterSchool registerSchool)
    {
        List<RegisterSchool> list = registerSchoolService.selectRegisterSchoolList(registerSchool);
        ExcelUtil<RegisterSchool> util = new ExcelUtil<RegisterSchool>(RegisterSchool.class);
        util.exportExcel(response, list, "注册-学校数据");
    }

    /**
     * 获取注册-学校详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(registerSchoolService.selectRegisterSchoolById(id));
    }

    /**
     * 新增注册-学校
     */
    @Log(title = "注册-学校", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RegisterSchool registerSchool)
    {
        return registerSchoolService.insertRegisterSchool(registerSchool);
    }

    /**
     * 修改注册-学校
     */
    @Log(title = "注册-学校", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody RegisterSchool registerSchool)
    {
        return toAjax(registerSchoolService.updateRegisterSchool(registerSchool));
    }

    /**
     * 删除注册-学校
     */
    @PreAuthorize("@ss.hasPermi('register:school:remove')")
    @Log(title = "注册-学校", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(registerSchoolService.deleteRegisterSchoolByIds(ids));
    }

    /**
     * 注册信息查询
     */
    @GetMapping(value = "/query")
    public AjaxResult queryInfo(String openId)
    {
        return registerSchoolService.queryInfo(openId);
    }

}
